"use strict";
/*******************************************************************************
 * Copyright (c) 2018 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const CommandUtil_1 = require("../command/CommandUtil");
const ProjectState_1 = require("../microclimate/project/ProjectState");
const Logger_1 = require("../Logger");
const StartModes_1 = require("../constants/StartModes");
const Requester_1 = require("../microclimate/project/Requester");
const MCUtil = require("../MCUtil");
function restartProjectCmd(project, debug) {
    return __awaiter(this, void 0, void 0, function* () {
        Logger_1.default.d("RestartProjectCmd invoked");
        if (project == null) {
            const selected = yield CommandUtil_1.promptForProject(ProjectState_1.default.AppStates.STARTED, ProjectState_1.default.AppStates.STARTING);
            if (selected == null) {
                // user cancelled
                Logger_1.default.d("User cancelled project prompt");
                return false;
            }
            project = selected;
        }
        const startMode = StartModes_1.getDefaultStartMode(debug, project.type.type);
        Logger_1.default.i(`RestartProject on project ${project.name} into ${startMode} mode`);
        return Requester_1.default.requestProjectRestart(project, startMode)
            .then((result) => __awaiter(this, void 0, void 0, function* () {
            const statusCode = Number((yield result).statusCode);
            // Note here that we don't return whether or not the restart actually suceeded,
            // just whether or not it was accepted by the server and therefore initiated.
            if (MCUtil.isGoodStatusCode(statusCode)) {
                Logger_1.default.d("Restart was accepted by server");
                onRestartAccepted(project);
                return true;
            }
            return false;
        }));
    });
}
exports.default = restartProjectCmd;
function onRestartAccepted(project) {
    return __awaiter(this, void 0, void 0, function* () {
        // first, expect the app to Stop
        try {
            yield project.waitForState(60 * 1000, ProjectState_1.default.AppStates.STOPPED);
        }
        catch (err) {
            Logger_1.default.e(`Project ${project.name} didn't stop after restart request!`);
            return;
        }
        // open the app's logs so we can watch the restart execute
        project.connection.logManager.getOrCreateAppLog(project.id, project.name).showOutputChannel();
        // The rest of the restart will proceed once the restart result event is received by the MCSocket.
        // See MCSocket.onProjectRestarted
    });
}
//# sourceMappingURL=RestartProjectCmd.js.map