"use strict";
/*******************************************************************************
 * Copyright (c) 2018 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const Logger_1 = require("../Logger");
// non-nls-file
const RES_FOLDER_NAME = "res";
const STYLE_FOLDER_NAME = "css";
const IMG_FOLDER_NAME = "img";
const LIGHT_FOLDER_NAME = "light";
const DARK_FOLDER_NAME = "dark";
function getResourcePath(...paths) {
    return path.join(global.__extRoot, RES_FOLDER_NAME, ...paths);
}
function getCss(filename) {
    return getResourcePath(STYLE_FOLDER_NAME, filename);
}
exports.getCss = getCss;
/**
 * Resolve the icon with the given name and return the paths to it,
 * which can then be assigned to a vscode iconPath (eg on a TreeItem).
 * If an icon cannot be found, an error is will be logged.
 *
 * A requested icon is always assumed to have a file in the 'dark' folder.
 * If there is a matching one in the 'light' folder, that will be used for light themes.
 *
 */
function getIconPaths(icon) {
    const darkPath = getResourcePath(IMG_FOLDER_NAME, DARK_FOLDER_NAME, icon);
    // make sure the file exists and is readable
    fs.access(darkPath, fs.constants.R_OK, (err) => {
        if (err) {
            Logger_1.default.e(`Dark icon not found! ${icon} - error:`, err);
        }
    });
    const lightPath = getResourcePath(IMG_FOLDER_NAME, LIGHT_FOLDER_NAME, icon);
    fs.access(lightPath, fs.constants.R_OK, (err) => {
        if (err) {
            Logger_1.default.e(`Light icon not found! ${icon} - error:`, err);
        }
    });
    return {
        light: lightPath,
        dark: darkPath
    };
}
exports.getIconPaths = getIconPaths;
var Icons;
(function (Icons) {
    Icons["Microclimate"] = "microclimate.svg";
    Icons["Disconnected"] = "disconnected.svg";
    // project types
    Icons["Microprofile"] = "lang_java.svg";
    Icons["Spring"] = "lang_java.svg";
    Icons["Node"] = "lang_node.svg";
    Icons["Swift"] = "lang_swift.svg";
    Icons["Python"] = "lang_python.svg";
    Icons["Go"] = "lang_go.svg";
    Icons["Docker"] = "lang_generic.svg";
    Icons["Generic"] = "lang_generic.svg";
})(Icons = exports.Icons || (exports.Icons = {}));
// https://octicons.github.com/
var Octicons;
(function (Octicons) {
    Octicons["sync"] = "sync";
    Octicons["bug"] = "bug";
})(Octicons = exports.Octicons || (exports.Octicons = {}));
/**
 * Get a string which can be included in a status bar message to render an octicon.
 * The returned value will be "$(iconName) or $(iconName~spin)"
 *
 * @param iconName - One of the octicons from https://octicons.github.com
 */
function getOcticon(iconName, spinning = false) {
    return `$(${iconName}${spinning ? "~spin" : ""})`;
}
exports.getOcticon = getOcticon;
//# sourceMappingURL=Resources.js.map