"use strict";
/*******************************************************************************
 * Copyright (c) 2018 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const ProjectType_1 = require("../microclimate/project/ProjectType");
const Logger_1 = require("../Logger");
// non-nls-file
// from https://github.ibm.com/dev-ex/microclimate/blob/master/docker/file-watcher/server/src/projects/constants.ts
var StartModes;
(function (StartModes) {
    StartModes["RUN"] = "run";
    StartModes["DEBUG"] = "debug";
    StartModes["DEBUG_NO_INIT"] = "debugNoInit";
})(StartModes || (StartModes = {}));
function getUserFriendlyStartMode(startMode) {
    switch (startMode) {
        case StartModes.RUN:
            return "run";
        case StartModes.DEBUG:
        // For now, debug vs debugNoInit is not exposed to the user. So in both cases it's just "Debug" to them.
        // return "debug (with initial break)";
        case StartModes.DEBUG_NO_INIT:
            return "debug";
        default:
            Logger_1.default.e(`Unknown start mode "${startMode}"!`);
            return "unknown";
    }
}
exports.getUserFriendlyStartMode = getUserFriendlyStartMode;
function allStartModes() {
    return [
        StartModes.RUN,
        StartModes.DEBUG,
        StartModes.DEBUG_NO_INIT
    ];
}
exports.allStartModes = allStartModes;
function isDebugMode(startMode) {
    return startMode === StartModes.DEBUG.toString() || startMode === StartModes.DEBUG_NO_INIT.toString();
}
exports.isDebugMode = isDebugMode;
function getDefaultStartMode(debug, projectType) {
    if (!debug) {
        return StartModes.RUN;
    }
    if (projectType === ProjectType_1.default.Types.MICROPROFILE) {
        return StartModes.DEBUG;
    }
    return StartModes.DEBUG_NO_INIT;
}
exports.getDefaultStartMode = getDefaultStartMode;
exports.default = StartModes;
//# sourceMappingURL=StartModes.js.map